//+------------------------------------------------------------------+
//|                                                   commission.mqh |
//|                                      Copyright 2017, nicholishen |
//|                         https://www.forexfactory.com/nicholishen |
//+------------------------------------------------------------------+
#property copyright "Copyright 2017, nicholishen"
#property link      "https://www.forexfactory.com/nicholishen"
#property strict
#include <suffix_filters.mqh>
#include <multi_symbol_timeframe.mqh>

double CommissionCalc(string symbol, double lots, double commission_per_100k_units)
{
   double res = (double)UnitsDepositCurrency(symbol);
   if(res<=0)
      return -1.;
   res = res/100000.0*commission_per_100k_units*lots;
   return MathCeil(res*100)/100;
}

int UnitsDepositCurrency(const string symbol)
{
   string currency_account = AccountInfoString(ACCOUNT_CURRENCY);
   string currency_base    = StringSubstr(symbol,0,3);
   string currency_counter = StringSubstr(symbol,3,3);
   int    contract_units   = (int)SymbolInfoDouble(symbol,SYMBOL_TRADE_CONTRACT_SIZE);
   if(contract_units <= 0)
      return -1;
   if(currency_account==currency_base)
      return contract_units;
   if(currency_account==currency_counter)
   {
      double bid = iBid(symbol);
      if(bid <= 0.)
      {
         Print(__FUNCTION__," ",ErrorDescription(GetLastError()));
         return -1;
      }
      return int((double)contract_units*bid);
   }
   string suffix = AssumedSuffix();
   int    total  = SymbolsTotal(false);
   for(int i=0;i<total;i++)
   {
      string mw_symbol  = SymbolName(i,false);
      if(suffix!="" && StringFind(mw_symbol,suffix)<0)
         continue;
      if(StringFind(mw_symbol,currency_account)>=0 && StringFind(mw_symbol,currency_base)>=0)
      {
         double bid = iBid(mw_symbol);
         if(bid <= 0.)
         {
            Print(__FUNCTION__," ",ErrorDescription(GetLastError()));
            return -1;
         }
         string mw_base    = StringSubstr(mw_symbol,0,3);
         string mw_counter = StringSubstr(mw_symbol,3,3);
         if(mw_base==currency_base)
            return int(double(contract_units)*bid);
         if(mw_counter==currency_base)
         {
            int mw_units      = (int)SymbolInfoDouble(mw_symbol,SYMBOL_TRADE_CONTRACT_SIZE);
            int counter_units = int((double)mw_units*bid);
            if(counter_units <= 0)
               return -1;
            return int(((double)contract_units * (double)mw_units) / (double)counter_units);
         }
         break;
      }
   }
   return -1;
}